<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
    xmlns:tei="http://www.oxygenxml.com/ns/doc/xsl"
    xmlns:prov="java:ro.sync.exml.workspace.api.PluginWorkspaceProvider"
    xmlns:work="java:ro.sync.exml.workspace.api.PluginWorkspace"
    xmlns:editorAccess="java:ro.sync.exml.workspace.api.editor.WSEditor"
    xmlns:saxon="http://saxon.sf.net/"
    xmlns:textpage="java:ro.sync.exml.workspace.api.editor.page.text.xml.WSXMLTextEditorPage"
    xmlns:authorPage="java:ro.sync.exml.workspace.api.editor.page.author.WSAuthorEditorPage"
    xmlns:ctrl="java:ro.sync.ecss.extensions.api.AuthorDocumentController"
    exclude-result-prefixes="xs xd"
    version="2.0">
 <xsl:param name="documentSystemID" as="xs:string"/>
 <xsl:template name="start">
   <xsl:variable name="workspace" select="prov:getPluginWorkspace()"/>
   <xsl:variable name="editorAccess" select="work:getEditorAccess($workspace, xs:anyURI($documentSystemID), 0)"/>
   <xsl:variable name="pageID" as="xs:string" select="editorAccess:getCurrentPageID($editorAccess)"/>
   <xsl:variable name="name" as="xs:string">
   <xsl:choose>
       <xsl:when test="$pageID='Text'">
          <xsl:variable name="textpage" select="editorAccess:getCurrentPage($editorAccess)"/>
          <!-- In the text page, the context is the @content attribute -->
          <xsl:value-of select="textpage:evaluateXPath($textpage, 'xs:string(./parent::node()/@name)')"/>
      </xsl:when>
      <xsl:when test="$pageID='Author'">
         <xsl:variable name="authorPage" select="editorAccess:getCurrentPage($editorAccess)"/>
         <xsl:variable name="caretOffset" select="authorPage:getCaretOffset($authorPage)"/>
         <xsl:variable name="ctrl" select="authorPage:getDocumentController($authorPage)"/>
         <xsl:variable name="contextNode" select="ctrl:getNodeAtOffset($ctrl, $caretOffset)"/>
         <!-- In the author page, the context is the "othermeta" element -->
         <xsl:value-of select="ctrl:evaluateXPath($ctrl, 'xs:string(@name)', $contextNode, false(), false(), false(), false())[1]"/>
     </xsl:when>
   </xsl:choose>
  </xsl:variable>
  <items>
   <xsl:choose>
	 <xsl:when test="$name = 'doctype'">
			<item value="Administration Guide">
			<item value="Announcement Letter">
			<item value="API Developer Guide">
			<item value="Application Note">
			<item value="Architectural and Engineering Guide">
			<item value="Area and Zone Guide">
			<item value="Best Practices Guide">
			<item value="Catalog Page">
			<item value="Certificate">
			<item value="Checklist">
			<item value="Commissioning Guide">
			<item value="Communications Setup Guide">
			<item value="Configuration Guide">
			<item value="Data Form">
			<item value="Datasheet">
			<item value="Declaration">
			<item value="Documentation Index">
			<item value="Engineering Guide">
			<item value="FAQ">
			<item value="Fixing Guide">
			<item value="Flash Sheet">
			<item value="Global Safety Data Sheet">
			<item value="Guide Specification">
			<item value="Hardening Guide">
			<item value="Important Product Information Letter">
			<item value="Installation Guide">
			<item value="Installation Operation and Maintenance Guide">
			<item value="Integration Guide">
			<item value="Internal Service">
			<item value="Letter">
			<item value="Logbook">
			<item value="Maintenance Guide">
			<item value="Operation Guide">
			<item value="Part List">
			<item value="Planning Guide">
			<item value="Point List">
			<item value="Product Application and Design Information">
			<item value="Product Bulletin">
			<item value="Product Catalog">
			<item value="Product Discontinuation Letter">
			<item value="Product Information Letter">
			<item value="Product Information Sheet">
			<item value="Product Recall Action Notice">
			<item value="Product Release Letter">
			<item value="Product Safety Alert">
			<item value="Product Update Action Notice">
			<item value="Protocol Implementation Conformance Statement">
			<item value="Quick Start Guide">
			<item value="Reference Guide">
			<item value="Release Notes">
			<item value="Retrofit Guide">
			<item value="Safety Sheet">
			<item value="Security and IT Guide">
			<item value="Service Bulletin">
			<item value="Service Guide">
			<item value="Service Information Letter">
			<item value="Setup Guide">
			<item value="Specification Engineering Data and Dimensions Guide">
			<item value="Specification Guide">
			<item value="Start Up Sheet">
			<item value="Submittal Drawing">
			<item value="Technical Bulletin">
			<item value="Technical Guide">
			<item value="Troubleshooting Guide">
			<item value="Upgrade Guide">
			<item value="User Guide">
			<item value="Warranty">
			<item value="White Paper">
			<item value="Wiring Diagram">
     </xsl:when>
     <xsl:when test="$name = 'product-status'">
        <item value="Active"/>
		<item value="Discontinued"/>
     </xsl:when>
   </xsl:choose>
  </items>
 </xsl:template>
</xsl:stylesheet>